@@ -240,7 +240,7 @@ void __bare_init imx_nand_load_image(void *dest, int size)
 #ifdef CONFIG_NAND_IMX_BOOT_DEBUG
 #include <command.h>
 
-static int do_nand_boot_test(struct command *cmdtp, int argc, char *argv[])
+static int do_nand_boot_test(int argc, char *argv[])
 {
 	void *dest;
 	int size;
