@@ -25,12 +25,13 @@
 #ifdef CONFIG_ARCH_OMAP3
 #include <mach/omap3-silicon.h>
 #endif
-
-/* If Architecture specific init functions are present */
-#ifdef CONFIG_ARCH_HAS_LOWLEVEL_INIT
-#ifndef __ASSEMBLY__
-void a_init(void);
-#endif /* __ASSEMBLY__ */
+#ifdef CONFIG_ARCH_OMAP4
+#include <mach/omap4-silicon.h>
 #endif
 
+/* If Architecture specific init functions are present */
+#ifndef __ASSEMBLY__
+void omap3_core_init(void);
+#endif /* __ASSEMBLY__ */
+
 #endif /* __ASM_ARCH_OMAP_SILICON_H */
