@@ -31,7 +31,7 @@ int altera_mem_malloc_init(void)
 {
 
 	mem_malloc_init((void *)(NIOS_SOPC_TEXT_BASE - MALLOC_SIZE),
-			(void *)(NIOS_SOPC_TEXT_BASE));
+			(void *)(NIOS_SOPC_TEXT_BASE - 1));
 
 	return 0;
 }
@@ -40,8 +40,5 @@ core_initcall(altera_mem_malloc_init);
 
 void arch_shutdown(void)
 {
-#ifdef CONFIG_USE_IRQ
-	disable_interrupts();
-#endif
 }
 
