@@ -28,7 +28,7 @@
 #include <errno.h>
 
 static struct device_d tap_device = {
-	.id	  = -1,
+	.id	  = DEVICE_ID_DYNAMIC,
         .name     = "tap",
 };
 
